package net.sergeych.crypto2

import kotlinx.serialization.Serializable

@Serializable
abstract class BinaryKeyBase() {

    abstract val keyBytes: UByteArray
    abstract val magick: KeysMagickNumber

    open val id by lazy { KeyId(magick, keyBytes) }

    override fun equals(other: Any?): Boolean {
        return other is BinaryKeyBase && other.keyBytes contentEquals keyBytes
    }

    override fun hashCode(): Int {
        return keyBytes.contentHashCode()
    }

    override fun toString(): String = keyBytes.encodeToBase64Url()

    companion object {

    }
}

open class IllegalSignatureException(text: String = "signed data is tampered or signature is corrupted") :
    IllegalStateException(text)

class ExpiredSignatureException(text: String) : IllegalSignatureException(text)